@@ -1,6 +1,8 @@
 # Crypt::CAST5_PP::Tables
 # S-box tables for CAST5 encryption
 
+use strict;
+use warnings;
 use integer;
 
 @Crypt::CAST5_PP::s1 = (
